@@ -1,12 +1,16 @@
+
 // SPDX-FileCopyrightText: 2022 Snehit Sah <hi@snehit.dev>
 // SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 
 #pragma once
 
 #include <QHash>
+#include <QList>
 #include <QObject>
+#include <QQmlEngine>
 #include <QString>
-#include <QVector>
+
+#include "neochatconnection.h"
 
 namespace Quotient
 {
@@ -23,6 +27,10 @@ class Room;
 class SpaceHierarchyCache : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
+
+    Q_PROPERTY(NeoChatConnection *connection READ connection WRITE setConnection NOTIFY connectionChanged)
 
 public:
     static SpaceHierarchyCache &instance()
@@ -30,19 +38,28 @@ public:
         static SpaceHierarchyCache _instance;
         return _instance;
     }
+    static SpaceHierarchyCache *create(QQmlEngine *engine, QJSEngine *)
+    {
+        engine->setObjectOwnership(&instance(), QQmlEngine::CppOwnership);
+        return &instance();
+    }
 
     /**
      * @brief Return the list of child rooms for the given space ID.
      */
-    [[nodiscard]] QVector<QString> &getRoomListForSpace(const QString &spaceId, bool updateCache);
+    [[nodiscard]] QList<QString> &getRoomListForSpace(const QString &spaceId, bool updateCache);
 
     /**
      * @brief Returns whether the space is a child space of any other space.
      */
     [[nodiscard]] bool isChildSpace(const QString &spaceId) const;
 
+    NeoChatConnection *connection() const;
+    void setConnection(NeoChatConnection *connection);
+
 Q_SIGNALS:
     void spaceHierarchyChanged();
+    void connectionChanged();
 
 private Q_SLOTS:
     void addSpaceToHierarchy(Quotient::Room *room);
@@ -51,8 +68,9 @@ private Q_SLOTS:
 private:
     explicit SpaceHierarchyCache(QObject *parent = nullptr);
 
-    QVector<QString> m_activeSpaceRooms;
-    QHash<QString, QVector<QString>> m_spaceHierarchy;
+    QList<QString> m_activeSpaceRooms;
+    QHash<QString, QList<QString>> m_spaceHierarchy;
     void cacheSpaceHierarchy();
     void populateSpaceHierarchy(const QString &spaceId);
+    NeoChatConnection *m_connection;
 };
